# SCRIPT WRITTENT WITH RSTUDIO TO ANALYZE MARCUS THEORY ELECTRON TRANSFERS FROM

# If you use this script or a part of it, please cite original publication.


#INPUT FILE:
#gap_rst${ID}_ct1_polok.dat :  time ([in fs], Energy state 1 [Ha); Energy state 2 [Ha]; gap [eV] ; HDA [eV] ; SDA  
#gap_rst${ID}_ct2_polok.dat :  time ([in fs], Energy state 1 [Ha); Energy state 2 [Ha]; gap [eV] ; HDA [eV] ; SDA

#OUTPUT FILE:
#FigureS7left.tiff
#FigureS7right.tiff
#FigureS10left.tiff
#FigureS10right.tiff
#FigureS9_1-11.tiff
#FigureS8TopLeft.tiff
#FigureS8TopRight.tiff
#FigureS8BottomLeft.tiff


#VARIABLES:
#gap_1		: vector gathering energy gaps on first PES for every trajectoires
#gap_2		: vector gathering energy gaps on first PES for every trajectories
#rem_gap1	: number of aberrant values discarded for each series in first PES
#rem_gap2       : number of aberrant values discarded for each series in second PES
#hda_1		: vector gathering electronic coupling on first PES for every trajectoires
#hda_2		: vector gathering electronic coupling on second PES for every trajectoires

## Marcus Theory parameters. Drop refers to the number of points collected to make the calculations
#ET_drop	: Vector ET characteristic time (1/rate constant)/
#lasV1_drop	: Vector with variance reorganization energy along MD on first PES
#lasV2_drop	: Vector with variance reorganization energy along MD on second PES
#laSt_drop	: Vector with Stokes reorganization energy 
#deltag_drop	: Vector with reation free energy 
#dgact_drop	: Vector with activation free energy
#kg_drop	: Ratio between Variance and Stokes reorganization energy

# Load packages
library(coda)

#Conversion factors
ev2ha=0.0367502
kcalmol2ua=0.00159362
kcalmol2ev=0.0433634
j2eV=6.24181e18
bohr=5.2917721092*1E-11

#Setting temperature
temp=298.

# Constants
kb=1.3806488e-23
hbar=1.054571726E-34
kbTeV=kb*temp*j2eV
kbTha=kbTeV*ev2ha



# Read Energy gap and electronic coupling from deMon2k outputs
	### Initialize vectors

gap_1 <- c()
rem_gap1 <- c()
gap_2 <- c()
rem_gap2 <- c()
hda_1 <- c()
hda_2 <- c()

	# Loop over the 11 sets of MD trajectories (each refered by an ID number)

for (ID in c(375,500,625,750,875,1000,1125,1750,1875,2000,2125)) {

	#Read values for MD on first PES.
    
   toto <- data.frame(read.table(file=paste('gap_rst',ID,'_ct1_polok.dat',sep=''),header=FALSE))
   
   		# Detect abberant values. We consider a value is abberant (because SCF failed)
      # if the variation of the vertical energy gap 
      # varies too much with respect to the average last two and following tow snapshots. 
      # We compute a percentage of variation with the average last  and next points (see formulas)
   	  # If the variations with previous and next gaps is larger than 50 or  100 % we discard points 
      # (actually we replace the gap and el. coupling by the average value).


   variam<-c(0,0,0,0)
   variap<-c(0,0,0,0)
   for (i in seq(5,length(toto[,4])-5,1)) {
     k=i-4
     l=i-2
     m=i+2
     n=i+4
     variam <- append(variam,100*(toto[i,4]-mean(toto[k:l,4]))/mean(toto[k:l,4]))
     variap <- append(variap,100*(toto[i,4]-mean(toto[m:n,4]))/mean(toto[m:n,4]))
   }
   for (i in seq(length(toto[,4])-4,length(toto[,4])-1,1)) {
     k=i-1
     m=i+1
     variam <- append(variam,100*(toto[i,4]-toto[k,4])/toto[k,4])
     variap <- append(variap,100*(toto[i,4]-toto[m,4])/toto[m,4])
   }
   j=0  
   for (i in seq(1,length(toto[,4])-1,1)) {
     if (variam[i] > 70 || variap[i] > 70) {print(c(i,variam[i],variap[i],"ABERRANT!!!"));
        toto[i,4] = toto[i-1,4] ; toto[i,5] = toto[i-1,5]; j=j+1 }
   }
   rem_gap1 <- cbind(rem_gap1,j)
   gap_1<- cbind(gap_1,toto[,4])
   hda_1<- cbind(hda_1,abs(toto[,5]))
   
        #Read values for MD on second PES, same strategy to remove aberrant values. Cutoff set to 50% of varaiation
 
   toto <- data.frame(read.table(file=paste('gap_rst',ID,'_ct2_polok.dat',sep=''),header=FALSE))
   variam<-c(0,0,0,0)
   variap<-c(0,0,0,0)
   for (i in seq(5,length(toto[,4])-5,1)) {
     k=i-4
     l=i-2
     m=i+2
     n=i+4
     variam <- append(variam,abs(100*(toto[i,4]-mean(toto[k:l,4]))/mean(toto[k:l,4])))
     variap <- append(variap,abs(100*(toto[i,4]-mean(toto[m:n,4]))/mean(toto[m:n,4])))
   }
   for (i in seq(length(toto[,4])-4,length(toto[,4])-1,1)) {
     k=i-1
     m=i+1
     variam <- append(variam,100*(toto[i,4]-toto[k,4])/toto[k,4])
     variap <- append(variap,100*(toto[i,4]-toto[m,4])/toto[m,4])
   }
   j =0
   for (i in seq(5,length(toto[,4])-1,1)) {
   
     if (variam[i] > 50 || variap[i] > 50)  {print(c(i,variam[i],variap[i],"ABERRANT!!!")); toto[i,4] = toto[i-1,4] ; toto[i,5] = toto[i-1,5]; j=j+1 }
   }
   rem_gap2 <- cbind(rem_gap2,j)
   gap_2<- cbind(gap_2,-toto[,4])
   hda_2<- cbind(hda_2,abs(toto[,5]))
}

# Percentage of discarded snapshots because of SCF failure, abrerrant values

100*(sum(rem_gap2)+sum(rem_gap1))/(2*length(gap_1[,1])*11)

# Save time from the last time series

xtime <- toto[,1]


######################################################################################################

#  Marcus Theory parameters calculations

ET_drop <-c()
u_ET_drop <- c()
lamV1_drop <- c()
lamV2_drop <- c()
lamSt_drop <- c()
deltag_drop <- c()
dgact_drop <- c()
kg_drop <- c()
dropx <- c(seq(50,100,10))

# We loop over endl which defines the length of the trajectory we include in the analysis
for (endl in seq(50,100,10)) {
  first=10 # This is because we discard the firt 10 snapshots (100 fs)
  deltag <- c()
  hda_sq <- c()
  dgact<-c()
  lamSt <- c()
  lamV1 <- c()
  lamV2 <- c()
  ET<- c()
  ETTUN <- c()
  u_dglSt <- c()
  u_lamV1 <- c()
  u_lamV2 <- c()
  u_dgact <- c()
  u_ET <- c()
  u_hda_sq <- c()
  
  # We loop over the 11 replicas 
  for (i in seq(1,11,1)) {
    hda_sq <- rbind(hda_sq,c(mean(hda_1[first:endl,i]^2),mean(hda_2[first:endl,i]^2)))
    u_hda_sq  <- rbind(u_hda_sq,c(var(hda_1[first:endl,i]^2)/effectiveSize(hda_1[first:endl,i]^2),
                                  var(hda_2[first:endl,i]^2)/effectiveSize(hda_2[first:endl,i]^2)))
    
    deltag<-rbind(deltag,0.5*(mean(gap_1[first:endl,i]) + mean(gap_2[first:endl,i])))
    u_dglSt <- rbind(u_dglSt,0.25*(var(gap_1[first:endl,i])/effectiveSize(gap_1[first:endl,i]) 
                                   + var(gap_2[first:endl,i])/effectiveSize(gap_2[first:endl,i])) )
    
    lamSt<-rbind(lamSt,0.5*(mean(gap_1[first:endl,i])-mean(gap_2[first:endl,i])))
    
    lamV1<-rbind(lamV1,var(gap_1[first:endl,i])/(2*kbTeV))
    u_lamV1<-rbind(u_lamV1,2*(var(gap_1[first:endl,i]))^2/(effectiveSize(gap_1[first:endl,i])*(2*kbTeV)^2))
    
    lamV2<-rbind(lamV2,var(gap_2[first:endl,i])/(2*kbTeV))
    u_lamV2<-rbind(u_lamV2,2*var(gap_2[first:endl,i])^2/(effectiveSize(gap_2[first:endl,i])*(2*kbTeV)^2))
    
    dgact<-rbind(dgact,((deltag[i]+lamSt[i])^2/(4*lamSt[i]))-mean(hda_1[,i]))
    u_dgact <- rbind(u_dgact,u_dglSt[i]*(deltag[i]+lamSt[i])/(4*lamSt[i])
                     +     u_dglSt[i]*(8*(deltag[i]+lamSt[i])*lamSt[i]-4*(deltag[i]+lamSt[i])^2)/16*lamSt[i]^2
                     +     var(hda_1[first:endl,i])/effectiveSize(hda_1[first:endl,i]))

    
    ET<- rbind(ET,1.E12/(2*hda_sq[i,1]*pi*exp(-dgact[i]/kbTeV)/(hbar*sqrt(4*pi*(lamSt[i])*kbTeV)*j2eV)))
  # ETTUN <- rbind(ETTUN,1.E12/(2*hda_sq[i,1]*pi/(hbar*sqrt(4*pi*(lamSt[i])*kbTeV)*j2eV)))
    ETTUN <- rbind(ETTUN,1.E12/(1.E13*exp(-dgact[i]/kbTeV)))
    
    C = 1.E12*hbar*sqrt(4*pi*kbTeV)*j2eV/((2*pi)*exp(-dgact[i]/kbTeV))
    u_ET <- rbind(u_ET,(C*(  u_hda_sq[i,1]*sqrt(lamSt[i])/hda_sq[i,1]^2 
                             + u_dglSt[i]/(2*hda_sq[i,1]*lamSt[i]^0.5)
                             + u_dgact[i]*sqrt(lamSt[i])/(hda_sq[i,1]*kbTeV))))
  }
  
  # Save results for this value of endl for later plotting
  ET_drop <- rbind(ET_drop,t(ET))
  u_ET_drop <- rbind(u_ET_drop,t(u_ET))
  lamV1_drop <- rbind(lamV1_drop,t(lamV1))
  lamV2_drop <- rbind(lamV2_drop,t(lamV2))
  lamSt_drop <- rbind(lamSt_drop,t(lamSt))
  deltag_drop <- rbind(deltag_drop,t(deltag))
  dgact_drop <- rbind(dgact_drop,t(dgact))
}

MTALL <- c()
MTALL <- cbind (MTALL,deltag)
MTALL <- cbind (MTALL,lamSt)
MTALL <- cbind (MTALL,lamV1)
MTALL <- cbind (MTALL,lamV2)
MTALL <- cbind (MTALL,dgact)
MTALL <- cbind (MTALL,ET)
MTALL <- cbind (MTALL,ETTUN)
colnames(MTALL) <- c("DeltaG","lamSt","lamV1","lamV2","Dgact","ETtau","ETtautun")


U_MTALL <- c()
U_MTALL <- cbind (U_MTALL,sqrt(u_dglSt))
U_MTALL <- cbind (U_MTALL,sqrt(u_dglSt))
U_MTALL <- cbind (U_MTALL,sqrt(u_lamV1))
U_MTALL <- cbind (U_MTALL,sqrt(u_lamV2))
U_MTALL <- cbind (U_MTALL,sqrt(u_dgact))

U_MTALL <- cbind (U_MTALL,sqrt(u_ET))
colnames(U_MTALL) <- c("uDeltaG","ulamSt","ulamV1","ulamV2","uDgact","uETtau")

#  DATA FOR Table 1 
format(MTALL,digit=2,scientific = FALSE)
format(U_MTALL,digit=1,scientific = FALSE)

######################################################################################################

# Plots of various quantities

# PLot energy gaps with respect to time

  #### Zoom on the first 50 fs.
  
tiff(filename = "FigureS7left.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )
last=30
xmin=1
xmax=last
ymin=min(c(min(gap_1[xmin:xmax,]),min(-gap_2[xmin:xmax])))
ymax=max(c(max(gap_1[xmin:xmax,]),max(-gap_2[xmin:xmax,])))
par(mar=c(5.5,5.5,2,2))
plot(xtime[1:last],-gap_2[1:last,1],ylim=c(ymin,ymax),type="l",lwd=2,col="seagreen4",axes=FALSE,xlab="",ylab="")
lines(xtime[1:last],gap_1[1:last,1],type="l",lwd=2,col="red3")
for (i in seq(2,11,1)) {
  lines(xtime[1:last],gap_1[1:last,i],type="l",lwd=2,col="red3")
  lines(xtime[1:last],-gap_2[1:last,i],type="l",lwd=2,col="seagreen4")
}
axis(1,at=seq(xtime[xmin],xtime[xmax],50),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(-2,ymax+1,1),pos=xmin,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="Time (fs)", 
      ylab="energy gap (eV)",cex.lab=1.75,line=4)

dev.off()

   ### Full
tiff(filename = "FigureS7right.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

last=500
xmin=1
xmax=last
ymin=min(c(min(gap_1[1:last,1]),min(-gap_2[1:last,1])))
ymax=max(c(max(gap_1[1:last,1]),max(-gap_2[1:last,1])))
par(mar=c(5.5,5.5,2,2))
plot(xtime[1:last],-gap_2[1:last,2],type="l",lwd=2,col="seagreen4",axes=FALSE,xlab="",ylab="")
lines(xtime[1:last],gap_1[1:last,2],type="l",lwd=2,col="red3")
for (i in seq(2,11,1)) {
  lines(xtime[1:last],gap_1[1:last,i],type="l",lwd=2,col="red3")
  lines(xtime[1:last],-gap_2[1:last,i],type="l",lwd=2,col="seagreen4")
}
axis(1,at=seq(xtime[xmin],xtime[xmax],50),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(0,ymax+1,1),pos=xmin,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="Time (fs)", 
      ylab="energy gap (eV)",cex.lab=1.75,line=4)

dev.off()


# Plot HDA Values with respect to time 
tiff(filename = "FigureS10left.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )

last=500
xmin=xtime[1]
xmax=xtime[last]
ymin=min(c(min(hda_1[1:last,]),min(hda_2[1:last,])))
ymax=max(c(max(hda_1[1:last,]),max(hda_2[1:last,])))

par(mar=c(5.5,5.5,2,2))

plot(xtime[1:last],hda_2[1:last,1],type="l",xlim=c(xmin,xmax),
     ylim=c(ymin,ymax+0.2),lwd=2,col="seagreen4",axes=FALSE,xlab="",ylab="")
lines(xtime[1:last],hda_1[1:last,1],type="l",lwd=2,col="red3")
for (i in seq(2,11,1)) {
  lines(xtime[1:last],hda_1[1:last,i],type="l",lwd=2,col="red3")
  lines(xtime[1:last],hda_2[1:last,i],type="l",lwd=2,col="seagreen4")
}
axis(1,at=seq(0,5000,1000),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(0,ymax+0.1,0.2),pos=xmin,cex.axis=1.75,lwd=2,las=1)

title(cex.main=1.75,xlab="Time (fs)", 
      ylab="Electronic coupling (abs. val.) (eV)",cex.lab=1.75,line=3)

dev.off()

# Plot histograms of HDA

tiff(filename = "FigureS10right.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )
binsize=0.003
i=1
histhda1<-hist(hda_1[1:last],breaks=seq(0.0,0.8,binsize),border="red3",
                    xlim=c(0.,0.2),ylim=c(0,70),xlab="Electronic coupling (abs. val.) (eV)",
                    cex.axis=1.75,cex.lab=1.75,lwd=6,axe=F,main = "")
par(new=TRUE)
histhda1<-hist(hda_2[1:last],breaks=seq(0.0,0.8,binsize),border="seagreen4",xlab="",ylab="",
                    xlim=c(0.,0.2),ylim=c(0,70),lwd=6,axe=F,main = "")
axis(1,at=seq(0,0.8,0.05),pos=0,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(0,70,10),pos=0,cex.axis=1.75,lwd=2,las=1)

dev.off()



# Plot Marcus parabolas
  
binsize=0.05
for (i in seq(1,11,1)) {

  # First build the histograms of the vertical energy gap on the two PES
  
  minh=min(c(gap_1[first:endl,i],gap_2[first:endl,i]))-binsize
  maxh=max(c(gap_1[first:endl,i],gap_2[first:endl,i]))+binsize
  exth=max(abs(minh),abs(maxh))
  
  histo1<-hist(gap_1[first:endl,i],breaks=seq(minh,maxh,binsize),
               border="red3",xlab=expression(paste(Delta,"E (eV)")),lwd=3)
  filled1 <- histo1$counts >= 2
  x1 <- histo1$mids[filled1]
  freq1 <- histo1$density[filled1]
  
  # Define the first free energy curve, and assume ergodic hypothesis to build the other free energy surface
  gnum <- as.data.frame(cbind(x1,-kbTeV*log(freq1),-kbTeV*log(freq1)+x1))
  names(gnum) <- c("de","act1","act2")
  g1min=min(gnum[,2])
  gnum[,2]<-gnum[,2]-g1min
  gnum[,3]<-gnum[,3]-g1min

  par(new=T)
  histo2<-hist(gap_2[first:endl,i],breaks=seq(minh,maxh,binsize),border="seagreen4",xlab=" ",axe=F,lwd=3)
  par(new=F)
  filled2 <- histo2$counts >= 2
  x2 <- histo2$mids[filled2]
  freq2 <- histo2$density[filled2]
  
  # Define the first free energy curve, and assume ergodic hypothesis to build the other free energy surface
  # Shift the second vertically the second curve with reaction free energy.
  
  gnum2 <- as.data.frame(cbind(x2,-kbTeV*log(freq2)-x2,-kbTeV*log(freq2)))
  names(gnum2) <- c("de","act1","act2")
  g2min=min(gnum2[,3])
  
  gnum2[,2]<-gnum2[,2]-g2min+deltag[i]
  gnum2[,3]<-gnum2[,3]-g2min+deltag[i]


# Fit computational poins with parabolas.
  gnum<- rbind(gnum,gnum2)
  fitg3  <- lm(act1~de+I(de^2),data=gnum,weights=c(histo1$counts[filled1],histo2$counts[filled2]))
  xmin1 <- -fitg3$coefficients[2]/(2.*fitg3$coefficients[3])

  fitg4  <- lm(act2~de+I(de^2),data=gnum,weights=c(histo1$counts[filled1],histo2$counts[filled2]))
  xmin2 <- -fitg4$coefficients[2]/(2.*fitg4$coefficients[3])

  xplot <- seq(-exth,exth,0.01)

  para3 <- predict(fitg3,newdata=data.frame(de=xplot))
  para4 <- predict(fitg4,newdata=data.frame(de=xplot))
  
  #Build adiabatic curves
  deter=(para3-para4)^2 +4*(mean(hda_1[first:endl,i])^2)
  adiabat1=0.5*(para3+para4-sqrt(deter))
  adiabat2=0.5*(para3+para4+sqrt(deter))

  tiff(filename = paste("FigureS9",i,".tiff",sep=""),
      width = 1500, height = 1200, units = "px", pointsize = 30,
      bg = "white",  res = NA,
      type = c("cairo", "Xlib", "quartz") )

  plot(-gnum[,1],gnum[,2],xlim=c(-exth,exth),ylim=c(-2,5.0),
       lwd=5,type="p",col="red3",axes=FALSE,xlab="",ylab="")
  points(-gnum[,1],gnum[,3],col="seagreen4",lwd=5)
  lines(-xplot,para3,col="red3",lwd=5)
  lines(-xplot,para4,col="seagreen4",lwd=5)
  lines(-xplot,adiabat1,col="grey28",lty=4,lwd=5)
  lines(-xplot,adiabat2,col="grey28",lty=4,lwd=5)
  
  segments(x0=-xmin1-1,y0=g2min+deltag[i],x1=-xmin2+1,y1=g2min+deltag[i],
           lwd=4,col="black",lty=2)
  segments(x0=-xmin1-1,y0=g2min,x1=-xmin2+1,y1=g2min,lwd=4,col="black",lty=2)
  segments(x0=-xmin1-1,y0=g2min+dgact[i]+mean(hda_1[,i]),x1=1,
           y1=g2min+dgact[i]+mean(hda_1[,i]),lwd=4,col="black",lty=2)
  
  arrows(x0=-xmin1,y1=g2min,x1=-xmin1,y0=g2min+deltag[i],lwd=6,
         col="black",angle=30,length=0.5)
  arrows(x0=1,y0=g2min,x1=1,y1=g2min+dgact[i]+mean(hda_1[,i]),lwd=5,
         col="black",angle=30,length=0.1)
  arrows(x0=-xmin2,y0=g2min,x1=-xmin2,y1=g2min+lamSt[i],lwd=5,
         col="black",angle=30,length=0.5)
  text(x=-xmin2+1,y=g2min+lamSt[i]/2,bquote(lambda^St),cex=1.75)
  text(x=2.2,y=g2min+2.*dgact[i],bquote(Delta*"Adia"^{act}),cex=1.75)
  text(x=-xmin1+1,y=g2min+deltag[i]/2,bquote(Delta*"A°"),cex=1.75)
  


  
  axis(1,at=seq(-trunc(exth),trunc(exth),1),pos=-2,cex.axis=1.75 ,lwd=2)
  axis(2,at=seq(-2,5,1),pos=-exth,cex.axis=1.75,lwd=2,las=1)
  
  title(cex.main=1.5, main= paste("Marcus Curve Set ",i,sep=""),xlab=expression(paste("-",Delta,"E (eV)")),
        ylab=expression(paste(Delta,"A (eV)")),cex.lab=1.75,line=2)
  
  dev.off()
}

######################################################################################

#   Plot Radial distribution functions

rdf_P_OW_1 <- data.frame(read.table(file="RDF/rdf_P_Owat_ct1_last300snap.dat",header=FALSE))
rdf_P_OW_2 <- data.frame(read.table(file="RDF/rdf_P_Owat_ct2_last300snap.dat",header=FALSE))
rdf_OU_HW_1 <- data.frame(read.table(file="RDF/rdf_Ouri_Hwat_ct1_last300snap.dat",header=FALSE))
rdf_OU_HW_2 <- data.frame(read.table(file="RDF/rdf_Ouri_Hwat_ct2_last300snap.dat",header=FALSE))
rdf_NU_OW_1 <- data.frame(read.table(file="RDF/rdf_Nuri_Owat_ct1_last300snap.dat",header=FALSE))
rdf_NU_OW_2 <- data.frame(read.table(file="RDF/rdf_Nuri_Owat_ct2_last300snap.dat",header=FALSE))
rdf_U_OW_1 <- data.frame(read.table(file="RDF/rdf_URI_Owat_ct1_last300snap.dat",header=FALSE))
rdf_U_OW_2 <- data.frame(read.table(file="RDF/rdf_URI_Owat_ct2_last300snap.dat",header=FALSE))


tiff(filename = "FigureS8TopLeft.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )


xmin=1.5
xmax=10.0
yminr=0.
ymaxr=max(c(rdf_P_OW_1[,2],rdf_P_OW_2[,2]))
yminir=0.0
ymaxir=max(c(rdf_P_OW_1[,3],rdf_P_OW_2[,3]))

par(mar=c(5, 4, 4, 8) + 0.1)

plot(rdf_P_OW_1[,1],rdf_P_OW_1[,2],xlim=c(xmin,xmax),ylim=c(0,0.001),type="l",lwd=4,col="red3",axes=FALSE,xlab="",ylab="")
lines(rdf_P_OW_2[,1],rdf_P_OW_2[,2],xlim=c(xmin,xmax),type="l",lwd=4,col="seagreen4")
axis(1,at=seq(xmin,xmax,0.5),pos=yminr,cex.axis=1.5,lwd=2)
axis(2,at=seq(0,0.001,0.0002),pos=xmin,cex.axis=1.5,lwd=2,las=1)

par(new=TRUE)
plot(rdf_P_OW_1[,1],rdf_P_OW_1[,3],xlim=c(xmin,xmax),ylim=c(0,50),type="l",lty=2,lwd=4,col="red3",axes=FALSE,xlab="",ylab="")
lines(rdf_P_OW_2[,1],rdf_P_OW_2[,3],xlim=c(xmin,xmax),type="l",lty=2,lwd=4,col="seagreen4")
axis(4,at=seq(0,50,5),pos=xmax,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="P-O distance (Ang.)", ylab="Radial Distr. Function",cex.lab=1.5,line=3)

mtext("Integration", side=4, line=3, cex=1.5,adj=0.5)

dev.off()




tiff(filename = "FigureS8TopRight.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )


xmin=1.5
xmax=10.0
yminr=0.
ymaxr=max(c(rdf_OU_HW_1[,2],rdf_OU_HW_2[,2]))
yminir=0.0
ymaxir=max(c(rdf_OU_HW_1[,3],rdf_OU_HW_2[,3]))
par(mar=c(5, 4, 4, 6) + 0.1)

plot(rdf_OU_HW_1[,1],rdf_OU_HW_1[,2],xlim=c(xmin,xmax),ylim=c(0,0.001),type="l",lwd=4,col="red3",axes=FALSE,xlab="",ylab="")
lines(rdf_OU_HW_2[,1],rdf_OU_HW_2[,2],xlim=c(xmin,xmax),type="l",lwd=4,col="seagreen4")
axis(1,at=seq(xmin,xmax,0.5),pos=yminr,cex.axis=1.5,lwd=2,xlab="Electronic coupling (abs. val.) (eV)")
axis(2,at=seq(0,0.001,0.0002),pos=xmin,cex.axis=1.5,lwd=2,las=1)

par(new=TRUE)
plot(rdf_OU_HW_1[,1],rdf_OU_HW_1[,3],xlim=c(xmin,xmax),ylim=c(0,10),type="l",lty=2,lwd=4,col="red3",axes=FALSE,xlab="",ylab="")
lines(rdf_OU_HW_2[,1],rdf_OU_HW_2[,3],xlim=c(xmin,xmax),type="l",lty=2,lwd=4,col="seagreen4")
axis(4,at=seq(0,50,1),pos=xmax,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="O(URI)-H(WAT) distance (Ang.)", ylab="Radial Distr. Function",cex.lab=1.5,line=3)

mtext("Integration", side=4, line=3, cex=1.5,adj=0.5)

dev.off()


tiff(filename = "FigureS8BottomLeft.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "Xlib", "quartz") )


xmin=1.5
xmax=10.0
yminr=0.
ymaxr=max(c(rdf_NU_OW_1[,2],rdf_NU_OW_2[,2]))
yminir=0.0
ymaxir=max(c(rdf_NU_OW_1[,3],rdf_NU_OW_2[,3]))
par(mar=c(5, 4, 4, 6) + 0.1)

plot(rdf_NU_OW_1[,1],rdf_NU_OW_1[,2],xlim=c(xmin,xmax),ylim=c(0,0.001),type="l",lwd=4,col="red3",axes=FALSE,xlab="",ylab="")
lines(rdf_NU_OW_2[,1],rdf_NU_OW_2[,2],xlim=c(xmin,xmax),type="l",lwd=4,col="seagreen4")
axis(1,at=seq(xmin,xmax,0.5),pos=yminr,cex.axis=1.5,lwd=2,xlab="Electronic coupling (abs. val.) (eV)")
axis(2,at=seq(0,0.001,0.0002),pos=xmin,cex.axis=1.5,lwd=2,las=1)

par(new=TRUE)
plot(rdf_NU_OW_1[,1],rdf_NU_OW_1[,3],xlim=c(xmin,xmax),ylim=c(0,10),type="l",lty=2,lwd=4,col="red3",axes=FALSE,xlab="",ylab="")
lines(rdf_NU_OW_2[,1],rdf_NU_OW_2[,3],xlim=c(xmin,xmax),type="l",lty=2,lwd=4,col="seagreen4")
axis(4,at=seq(0,10,1),pos=xmax,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="N(URI)-O(WAT) distance (Ang.)", ylab="Radial Distr. Function",cex.lab=1.5,line=3)

mtext("Integration", side=4, line=3, cex=1.5,adj=0.5)

dev.off()


