

#INPUT FILE:
#gap_rst${ID}_ct1_{XC}.dat with ID being the trajectory index and XC the exchange-correlation functional
#Each gap* file contains: time [in fs], Energy state 1 [Ha); Energy state 2 [Ha]; gap [eV] ; HDA [eV] ; overlap between diabats
#deco_rst{ID}_ct1_{XC}.dat: intsantaneous inverse of squared decoherence time [atomic units]; Sum_over_n [ 2*a_n/ ((F_ni - F_nf)^2) ] see Eq. 7 from article.  1st column: n runs over all nuclear degrees of freedom; 2nd column: n runs over USP nuclei; 3rd column: n runs over solvent molecule's nuclei.  

#OUTPUT FILE:
#FigureS11Left.tiff: 
#

# Load packages
library(coda)

#Conversion factors
ev2ha=0.0367502
j2eV=6.24181e18
bohr=5.2917721092*1E-11
s2fs=1.E15
aut2fs=48.3776865301  # Atomic unit of time to fs

#Setting temperature
temp=298.

# Constants
kb=1.3806488e-23
hbar=1.054571726E-34
kbTeV=kb*temp*j2eV
kbTha=kbTeV*ev2ha
  

# Define functions
#  find n!
findfact <- function(n){
  factorial <- 1
  if(n==0 | n==1){
    factorial <- 1
  } else{
    while(n >= 1){
      factorial <- factorial * n
      n <- n-1
    }
  }
  return (factorial)
}

#  find n!!
find2fact <- function(n){
  factorial <- 1
  if(n==0 | n==1){
    factorial <- 1
  } else{
    while(n >= 1){
      factorial <- factorial * n
      n <- n-2
    }
  }
  return (factorial)
}

# find 2nd order decoherence based hopping probability 
# mu should be given in atomic units
finddec2p <- function(mu,jmax){
  hp <- 0
  mu2 = -8*mu*mu
  j <- 1
  if(jmax < 1){
    hp <- -1
  } else{
    while(j <= jmax){
      hp <- hp + ((mu2)^(j-1))/find2fact(2*j-1)
      j <- j + 1
    }
  }
  hp <- hp*4*mu*mu
  return (hp)
}


# Read Energy gap and electronic coupling values from gap* files 
### Initialize vectors

gap_1 <- c() # time series of vertical energy gap
hda_1 <- c() # time series of electronic coupling
taud <- c()  # characteristic decoherence time (total)
taudqm <- c() # characteristic decoherence time (USP, QM region)
taudmm <- c() characteristic decoherence time (solvent, MM region)
nbtraj = 0

# Loop over the sets of MD trajectories (each referred by an ID number)
XC='pbe50'

for (ID in seq(100,2100,100)) {
  nbtraj = nbtraj + 1
  
  #Read values of energy gap and electronic coupling
  
  toto <- data.frame(read.table(file=paste('gap_rst',ID,'_ct1_',XC,'.dat',sep=''),header=FALSE))
  gap_1<- cbind(gap_1,toto[,4])
  hda_1<- cbind(hda_1,abs(toto[,5]))
  
  #Read decoherence time (^-0.5)  
  
  toto <- data.frame(read.table(file=paste('deco_rst',ID,'_ct1_',XC,'.dat',sep=''),header=FALSE))
  taud <- cbind(taud,toto[,4])
  taudqm <- cbind(taudqm,toto[,5])
  taudmm <- cbind(taudmm,toto[,6])
}
# Create time series

xtime <- c()
for (j in seq(1,length(gap_1[,nbtraj]),1)) {
  xtime <- rbind(xtime,j*0.5)
}

# Average energy gap
mgap_1 <-c()
for (j in seq(1,length(gap_1[,nbtraj])-1,1)) {
  mgap_1 <- rbind(mgap_1,mean(gap_1[j,]))
}
# Average electronic coupling 
mhda_1 <-c()
for (j in seq(1,length(hda_1[,nbtraj])-1,1)) {
  mhda_1 <- rbind(mhda_1,mean(hda_1[j,]))
}



###############################################################################################
# Determine mean first passage and Landau-Zener-Stuckelberg hopping probabilities


        # Seam crossing
jtauFP <- c()
tauFP <-c()
tauFPcross <-c()
trjcross = 0
for (ID in seq(1,nbtraj,1)) {
  crossing = FALSE
  for (j in seq(1,length(gap_1[,ID])-1,1)) {
    if ((gap_1[j,ID]*gap_1[j+1,ID] < 0.0) && (crossing == FALSE)) {
      crossing = TRUE
      jtauFP <- cbind(jtauFP,j)
      tauFP <- cbind(tauFP,xtime[j])
      tauFPcross = cbind(tauFPcross, xtime[j])
      trjcross = trjcross + 1
    }
  }
 if (crossing == FALSE) {
   jtauFP <- cbind(jtauFP,-1)
   tauFP <- cbind(tauFP,-1)
    }
}

      # LZS hopping probabilities
      # energies are given in eV and time in fs, hbar has to be converted in eV.fs in LZS formula.
swrate <- c() # Sweeping rate 
swratecross <- c() # Sweeping rate at the moment of crossing
hdacross <- c() # Electronic coupling at the moment of crossing
lzsp <- c()  # Landau Zener hopping probability
lzspcross <- c()

for (ID in seq(1,nbtraj,1)) {
  if (tauFP[ID] != -1) {
    swrate <- cbind(swrate,mean(gap_1[jtauFP[ID]:jtauFP[ID]+1,ID])/
                 (xtime[jtauFP[ID]+1]-xtime[jtauFP[ID]]))
    swratecross = cbind(swratecross,abs(swrate[,ID]))
    
    hdacross = cbind(hdacross,mean(hda_1[jtauFP[ID]:jtauFP[ID],ID]))

    lzsp <- cbind(lzsp, (1 - exp(-2*pi*(mean(hda_1[jtauFP[ID]:jtauFP[ID],ID]))^2
                                 /(abs(swrate[ID])*hbar*j2eV*s2fs))))
    lzspcross <- cbind(lzspcross,lzsp[,ID])
  }  
  else {
    swrate <- cbind(swrate,-1)
    lzsp <- cbind(lzsp,-1)
  }
}


  # Decoherence corrected hopping probabilities
  # The reciprocal squared decoherence time are given in atomic units of time.

mean(taud)^-0.5/aut2fs
mu=(mean(taud)^-0.5)*mean(hda_1[,])*ev2ha
dec1p=4*mu^2/(1+4*mu^2)
jmax=10
dec2p=finddec2p(mu,jmax)

# Build Table 2  for article
Tab2 <- c()
Tab2 <- cbind(Tab2,mean(taud)^-0.5/aut2fs)
Tab2 <- cbind(Tab2,mean(tauFPcross))
Tab2 <- cbind(Tab2,mean(swratecross))
Tab2 <- cbind(Tab2,mean(hdacross))
Tab2 <- cbind(Tab2,mean(lzspcross))
Tab2 <- cbind(Tab2,dec1p)
Tab2 <- cbind(Tab2,1/(mean(lzspcross)/mean(tauFPcross)))
Tab2 <- cbind(Tab2,1/(dec1p/mean(tauFPcross)))
colnames(Tab2) <- c("tdec","tMFP","sweeprate","Hif","LZS hp","dec1p hp","tET LZS","tET de1cp")


###############################################################################################
  
# PLot energy gaps with respect to time

png(filename = "FigureS11Left.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )
first=1
last=99
xmin=0.0
xmax=last
ymin=min(gap_1[xmin:xmax,])
ymax=max(gap_1[xmin:xmax,])

par(mar=c(4.5,5.5,2,2))
plot(xtime[first:last],gap_1[first:last,1],ylim=c(ymin,ymax),
     type="l",lwd=2,col="red3",axes=FALSE,xlab="",ylab="")
for (i in seq(2,21,1)) {
  lines(xtime[first:last],gap_1[first:last,i],type="l",lwd=2,col="red3")
}
lines(xtime[first:last],mgap_1[first:last],type="l",lwd=5,col="black")

axis(1,at=seq(0,xtime[last],5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(-2,ymax+1,1),pos=xmin,cex.axis=1.5,lwd=2,las=1)

title(cex.main=1.75,xlab="Time (fs)", ylab="energy gap (eV)",cex.lab=1.75,line=2)

dev.off()


# PLot electronic coupling with respect to time

png(filename = "FigureS11Right.tiff",
    width = 1500, height = 1200, units = "px", pointsize = 30,
    bg = "white",  res = NA,
    type = c("cairo", "cairo-png", "Xlib", "quartz") )
first=1
last=99
xmin=0.0
xmax=last
ymin=min(hda_1[xmin:xmax,])
ymax=max(hdA_1[xmin:xmax,])

par(mar=c(4.5,5.5,2,2))
plot(xtime[first:last],hda_1[first:last,1],ylim=c(ymin,0.2),
     type="l",lwd=2,col="red3",axes=FALSE,xlab="",ylab="")
for (i in seq(2,21,1)) {
  lines(xtime[first:last],hda_1[first:last,i],type="l",lwd=2,col="red3")
}
lines(xtime[first:last],mhda_1[first:last],type="l",lwd=4,col="black")
axis(1,at=seq(0,100,5),pos=ymin,cex.axis=1.75 ,lwd=2)
axis(2,at=seq(-2,ymax+0.2,0.05),pos=xmin,cex.axis=1.75,lwd=2,las=1)

title(xlab="Time (fs)",cex.lab=1.75,line=2)
title(ylab="electronic coupling (eV)",cex.lab=1.75,line=3)

dev.off()
